@@ -1,14 +1,13 @@
 from huaweisms.api.common import post_to_url, ApiCtx, get_from_url
-from .config import API_URL
 
 
 def status(ctx: ApiCtx):
-    url = "{}/ussd/status".format(API_URL)
+    url = "{}/ussd/status".format(ctx.api_base_url)
     return get_from_url(url, ctx)
 
 
 def get(ctx: ApiCtx):
-    url = "{}/ussd/get".format(API_URL)
+    url = "{}/ussd/get".format(ctx.api_base_url)
     return get_from_url(url, ctx)
 
 
@@ -26,7 +25,6 @@ def send(ctx: ApiCtx, msg: str):
         '__RequestVerificationToken': ctx.token,
         'X-Requested-With': 'XMLHttpRequest'
     }
-    url = "{}/ussd/send".format(API_URL)
+    url = "{}/ussd/send".format(ctx.api_base_url)
     r = post_to_url(url, xml_data, ctx, headers)
     return r
-
